Learn R Programming

netdiffuseR (version 1.16.7)

classify_graph: Analyze an R object to identify the class of graph (if any)

Description

Analyze an R object to identify the class of graph (if any)

Usage

classify_graph(graph)

Arguments

graph
Any class of accepted graph format (see netdiffuseR-graphs).

Value

Whe the object fits any of the accepted graph formats, a list of attributes including
type
Character scalar. Whether is a static or a dynamic graph
class
Character scalar. The class of the original object
ids
Character vector. Labels of the vertices
pers
Integer vector. Labels of the time periods
nper
Integer scalar. Number of time periods
n
Integer scalar. Number of vertices in the graph
Otherwise returns with error.

Details

This function analyzes an R object and tries to classify it among the accepted classes in netdiffuseR. If the object fails to fall in one of the types of graphs the function returns with an error indicating what (and when possible, where) the problem lies.

The function was designed to be used with as_diffnet.

See Also

as_diffnet, netdiffuseR-graphs