cumulative_adopt_count: Cummulative count of adopters
Description
For each time period, calculates the number of adopters, the proportion of adopters,
and the adoption rate.
Usage
cumulative_adopt_count(obj)
Arguments
obj
A $n * T$ matrix (Cumulative adoption matrix obtained from
toa_mat) or a diffnet object. Value
A $3 * T$ matrix, where its rows contain the number of adoptes, the proportion of
adopters and the rate of adoption respectively, for earch period of time.
Details
The rate of adoption--returned in the 3rd row out the resulting
matrix--is calculated as$$\frac{q_t - q_{t-1}}{q_{t-1}}$$
where $q(i)$ is the number of adopters in time $t$. Note that
it is only calculated fot $t>1$.