Learn R Programming

netdiffuseR (version 1.16.7)

fakesurvey: Fake survey data

Description

This data frame is used to ilustrate some of the functions of the package, in particular, the survey_to_diffnet function. This dataset can be merged with the fakeEdgelist.

Arguments

Format

A data frame with 9 rows and 9 variables
id
Unique id at group level
toa
Time of adoption
group
Group id
net1
Network nomination 1
net2
Network nomination 2
net3
Network nomination 3
age
Age of the respondent
gender
Gende of the respondent
note
Descroption of the respondent

Generated for the package.

See Also

Other diffusion datasets: brfarmersDiffNet, brfarmers, diffusion-data, fakeDynEdgelist, fakeEdgelist, fakesurveyDyn, kfamilyDiffNet, kfamily, medInnovationsDiffNet, medInnovations