grid_distribution(x, y, nlevels = 100L)nlevels with the class marks for xnlevels with the class marks for ynlevels by nlevels with the distribution
of the elements in terms of frecuency# Generating random vectors of size 100 x <- rnorm(100) y <- rnorm(100) # Calculating distribution grid_distribution(x,y,20)
plot_infectsuscep