Learn R Programming

netdiffuseR (version 1.16.7)

round_to_seq: Takes a numeric vector and maps it into a finite length sequence

Description

Takes a numeric vector and maps it into a finite length sequence

Usage

round_to_seq(x, nlevels = 20, as_factor = FALSE)

Arguments

x
A numeric or integer vector.
nlevels
Integer scalar. Length of the sequence to be map onto.
as_factor
Logical scalar. When TRUE the resulting vector is factor.

Value

A vector of length length(x) with values mapped to a sequence with nlevels unique valuess

Examples

Run this code

x <- rnorm(100)
w <- data.frame(as.integer(round_to_seq(x, as_factor = TRUE)),x)
plot(w,x)

Run the code above in your browser using DataLab